@@ -260,13 +260,16 @@ def main():
             else:
                 plugin = DEFAULT_PLUGIN
             if isinstance(package, dict):
-                package = package["name"]
-            want.setdefault(plugin, set()).add(package)
+                name = package["name"]
+            else:
+                name = package
+            want.setdefault(plugin, dict())[name] = package
         for plugin in plugins:
             print(f"Scanning current package state for {plugin.id()}...")
             installed = set(plugin.installed())
-            add[plugin.id()] = want.get(plugin.id(), set()) - installed
-            remove[plugin.id()] = installed - want.get(plugin.id(), set())
+            plugin_want = want.get(plugin.id(), dict())
+            add[plugin.id()] = [plugin_want[p] for p in plugin_want.keys() - installed]
+            remove[plugin.id()] = installed - plugin_want.keys()
 
         if args.dry_run:
             print(
